#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_MLOGEPS2_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_MLOGEPS2_HPP_INCLUDED

#include <boost/simd/constant/include/constants/mlogeps2.hpp>

#endif
